@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 1.875a.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 31 "asn1-parse.y"
+#line 30 "asn1-parse.y"
 
 #include <config.h>
 #include <stdlib.h>
@@ -174,7 +174,7 @@
 /* constants used in the grammar */
 enum {
   CONST_EXPLICIT = 1,
-  CONST_IMPLICIT,
+  CONST_IMPLICIT
 };
 
 struct parser_control_s {
@@ -205,13 +205,13 @@ struct parser_control_s {
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 77 "asn1-parse.y"
+#line 76 "asn1-parse.y"
 typedef union YYSTYPE {
   unsigned int constant;
   char str[MAX_STRING_LENGTH];
   AsnNode node;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
+/* Line 186 of yacc.c.  */
 #line 216 "asn1-parse.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -221,7 +221,7 @@ typedef union YYSTYPE {
 
 
 /* Copy the second part of user declarations.  */
-#line 83 "asn1-parse.y"
+#line 82 "asn1-parse.y"
 
 static AsnNode new_node (struct parser_control_s *parsectl, node_type_t type);
 #define NEW_NODE(a)  (new_node (PARSECTL, (a)))
@@ -242,25 +242,18 @@ static void yyerror (const char *s);
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
-# ifndef YYFREE
-#  define YYFREE free
-# endif
-# ifndef YYMALLOC
-#  define YYMALLOC malloc
-# endif
-
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# ifdef YYSTACK_USE_ALLOCA
-#  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
+# if YYSTACK_USE_ALLOCA
+#  define YYSTACK_ALLOC alloca
 # else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
-#   ifdef __GNUC__
-#    define YYSTACK_ALLOC __builtin_alloca
+#  ifndef YYSTACK_USE_ALLOCA
+#   if defined (alloca) || defined (_ALLOCA_H)
+#    define YYSTACK_ALLOC alloca
+#   else
+#    ifdef __GNUC__
+#     define YYSTACK_ALLOC __builtin_alloca
+#    endif
 #   endif
 #  endif
 # endif
@@ -273,20 +266,20 @@ static void yyerror (const char *s);
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC YYMALLOC
-#  define YYSTACK_FREE YYFREE
+#  define YYSTACK_ALLOC malloc
+#  define YYSTACK_FREE free
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
+	 || (YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short int yyss;
+  short yyss;
   YYSTYPE yyvs;
   };
 
@@ -296,13 +289,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
+     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if defined (__GNUC__) && 1 < __GNUC__
+#  if 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -338,7 +331,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short int yysigned_char;
+   typedef short yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -401,7 +394,7 @@ static const unsigned char yytranslate[] =
 #if YYDEBUG
 /* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
    YYRHS.  */
-static const unsigned short int yyprhs[] =
+static const unsigned short yyprhs[] =
 {
        0,     0,     3,     4,     7,     9,    12,    15,    17,    19,
       21,    23,    25,    27,    31,    36,    38,    42,    44,    47,
@@ -460,20 +453,20 @@ static const yysigned_char yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short int yyrline[] =
+static const unsigned short yyrline[] =
 {
-       0,   163,   163,   164,   167,   168,   171,   178,   179,   182,
-     183,   186,   187,   190,   195,   203,   204,   211,   216,   227,
-     232,   240,   242,   249,   250,   251,   254,   260,   268,   270,
-     275,   282,   287,   292,   299,   303,   309,   320,   326,   330,
-     336,   342,   351,   355,   361,   365,   373,   374,   381,   382,
-     389,   391,   398,   400,   407,   408,   415,   417,   424,   425,
-     434,   435,   436,   437,   438,   439,   440,   446,   454,   458,
-     465,   469,   477,   485,   491,   496,   503,   504,   505,   506,
-     507,   508,   509,   510,   511,   512,   513,   514,   515,   521,
-     525,   536,   540,   547,   554,   561,   563,   570,   575,   580,
-     589,   594,   599,   608,   615,   619,   631,   638,   645,   654,
-     663,   664,   667,   669,   676,   685,   686,   699,   700,   703
+       0,   162,   162,   163,   166,   167,   170,   177,   178,   181,
+     182,   185,   186,   189,   194,   202,   203,   210,   215,   226,
+     231,   239,   241,   248,   249,   250,   253,   259,   267,   269,
+     274,   281,   286,   291,   298,   302,   308,   319,   325,   329,
+     335,   341,   350,   354,   360,   364,   372,   373,   380,   381,
+     388,   390,   397,   399,   406,   407,   414,   416,   423,   424,
+     433,   434,   435,   436,   437,   438,   439,   445,   453,   457,
+     464,   468,   476,   484,   490,   495,   502,   503,   504,   505,
+     506,   507,   508,   509,   510,   511,   512,   513,   514,   520,
+     524,   535,   539,   546,   553,   560,   562,   569,   574,   579,
+     588,   593,   598,   607,   614,   618,   630,   637,   644,   653,
+     662,   663,   666,   668,   675,   684,   685,   698,   699,   702
 };
 #endif
 
@@ -482,35 +475,35 @@ static const unsigned short int yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "\"::=\"", "NUM", "IDENTIFIER",
-  "OPTIONAL", "INTEGER", "SIZE", "OCTET", "STRING", "SEQUENCE", "BIT",
-  "UNIVERSAL", "PRIVATE", "APPLICATION", "DEFAULT", "CHOICE", "OF",
-  "OBJECT", "STR_IDENTIFIER", "BOOLEAN", "TRUE", "FALSE", "TOKEN_NULL",
-  "ANY", "DEFINED", "BY", "SET", "EXPLICIT", "IMPLICIT", "DEFINITIONS",
-  "TAGS", "BEGIN", "END", "UTCTime", "GeneralizedTime", "FROM", "IMPORTS",
-  "ENUMERATED", "UTF8STRING", "NUMERICSTRING", "PRINTABLESTRING",
-  "TELETEXSTRING", "IA5STRING", "UNIVERSALSTRING", "BMPSTRING", "'+'",
-  "'-'", "'('", "')'", "','", "'['", "']'", "'{'", "'}'", "'.'", "$accept",
-  "input", "pos_num", "neg_num", "pos_neg_num", "num_identifier",
-  "pos_neg_identifier", "constant", "constant_list", "identifier_list",
-  "obj_constant", "obj_constant_list", "class", "tag_type", "tag",
-  "default", "integer_def", "boolean_def", "Time", "size_def2", "size_def",
-  "octet_string_def", "utf8_string_def", "numeric_string_def",
-  "printable_string_def", "teletex_string_def", "ia5_string_def",
-  "universal_string_def", "bmp_string_def", "string_def", "bit_element",
-  "bit_element_list", "bit_string_def", "enumerated_def", "object_def",
-  "type_assig_right", "type_assig_right_tag",
-  "type_assig_right_tag_default", "type_assig", "type_assig_list",
-  "sequence_def", "set_def", "choise_def", "any_def", "type_def",
-  "constant_def", "type_constant", "type_constant_list", "definitions_id",
-  "imports_def", "explicit_implicit", "definitions", 0
+  "$end", "error", "$undefined", "\"::=\"", "NUM", "IDENTIFIER", "OPTIONAL", 
+  "INTEGER", "SIZE", "OCTET", "STRING", "SEQUENCE", "BIT", "UNIVERSAL", 
+  "PRIVATE", "APPLICATION", "DEFAULT", "CHOICE", "OF", "OBJECT", 
+  "STR_IDENTIFIER", "BOOLEAN", "TRUE", "FALSE", "TOKEN_NULL", "ANY", 
+  "DEFINED", "BY", "SET", "EXPLICIT", "IMPLICIT", "DEFINITIONS", "TAGS", 
+  "BEGIN", "END", "UTCTime", "GeneralizedTime", "FROM", "IMPORTS", 
+  "ENUMERATED", "UTF8STRING", "NUMERICSTRING", "PRINTABLESTRING", 
+  "TELETEXSTRING", "IA5STRING", "UNIVERSALSTRING", "BMPSTRING", "'+'", 
+  "'-'", "'('", "')'", "','", "'['", "']'", "'{'", "'}'", "'.'", 
+  "$accept", "input", "pos_num", "neg_num", "pos_neg_num", 
+  "num_identifier", "pos_neg_identifier", "constant", "constant_list", 
+  "identifier_list", "obj_constant", "obj_constant_list", "class", 
+  "tag_type", "tag", "default", "integer_def", "boolean_def", "Time", 
+  "size_def2", "size_def", "octet_string_def", "utf8_string_def", 
+  "numeric_string_def", "printable_string_def", "teletex_string_def", 
+  "ia5_string_def", "universal_string_def", "bmp_string_def", 
+  "string_def", "bit_element", "bit_element_list", "bit_string_def", 
+  "enumerated_def", "object_def", "type_assig_right", 
+  "type_assig_right_tag", "type_assig_right_tag_default", "type_assig", 
+  "type_assig_list", "sequence_def", "set_def", "choise_def", "any_def", 
+  "type_def", "constant_def", "type_constant", "type_constant_list", 
+  "definitions_id", "imports_def", "explicit_implicit", "definitions", 0
 };
 #endif
 
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short int yytoknum[] =
+static const unsigned short yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -584,7 +577,7 @@ static const unsigned char yydefact[] =
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
-static const short int yydefgoto[] =
+static const short yydefgoto[] =
 {
       -1,     1,   160,   161,   162,    10,   204,   131,   132,    27,
       11,    12,   119,    64,    65,   191,    66,    67,    68,    93,
@@ -597,7 +590,7 @@ static const short int yydefgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -144
-static const short int yypact[] =
+static const short yypact[] =
 {
     -144,    38,  -144,   -18,    18,  -144,   105,     0,  -144,    12,
     -144,  -144,     1,  -144,  -144,    39,    63,  -144,  -144,    71,
@@ -623,7 +616,7 @@ static const short int yypact[] =
 };
 
 /* YYPGOTO[NTERM-NUM].  */
-static const short int yypgoto[] =
+static const short yypgoto[] =
 {
     -144,  -144,  -144,  -144,  -143,  -119,  -144,    33,  -144,  -144,
      -12,   -40,  -144,  -144,  -144,  -144,  -144,  -144,  -144,    96,
@@ -663,7 +656,7 @@ static const unsigned char yytable[] =
        0,   192
 };
 
-static const short int yycheck[] =
+static const short yycheck[] =
 {
       12,    41,    65,    45,   123,     4,     5,     4,   127,     5,
       52,     4,     5,   156,    56,    57,    58,    59,    60,    61,
@@ -738,7 +731,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrorlab
+#define YYERROR		goto yyerrlab1
 
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
@@ -773,11 +766,11 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)         \
+  Current.first_line   = Rhs[1].first_line;      \
+  Current.first_column = Rhs[1].first_column;    \
+  Current.last_line    = Rhs[N].last_line;       \
+  Current.last_column  = Rhs[N].last_column;
 #endif
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
@@ -821,17 +814,17 @@ do {								\
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (included).                                                   |
+| TOP (cinluded).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short int *bottom, short int *top)
+yy_stack_print (short *bottom, short *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short int *bottom;
-    short int *top;
+    short *bottom;
+    short *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -861,9 +854,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylno = yyrline[yyrule];
+  unsigned int yylineno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylno);
+             yyrule - 1, yylineno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -900,7 +893,7 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
+#if YYMAXDEPTH == 0
 # undef YYMAXDEPTH
 #endif
 
@@ -1098,9 +1091,9 @@ int yynerrs;
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short int yyssa[YYINITDEPTH];
-  short int *yyss = yyssa;
-  register short int *yyssp;
+  short	yyssa[YYINITDEPTH];
+  short *yyss = yyssa;
+  register short *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1137,7 +1130,6 @@ int yynerrs;
   yyssp = yyss;
   yyvsp = yyvs;
 
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1163,7 +1155,7 @@ int yynerrs;
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1191,7 +1183,7 @@ int yynerrs;
 	yystacksize = YYMAXDEPTH;
 
       {
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1324,17 +1316,17 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 167 "asn1-parse.y"
+#line 166 "asn1-parse.y"
     { strcpy(yyval.str,yyvsp[0].str); }
     break;
 
   case 5:
-#line 168 "asn1-parse.y"
+#line 167 "asn1-parse.y"
     { strcpy(yyval.str,yyvsp[0].str); }
     break;
 
   case 6:
-#line 172 "asn1-parse.y"
+#line 171 "asn1-parse.y"
     {
                   strcpy(yyval.str,"-");
                   strcat(yyval.str,yyvsp[0].str);
@@ -1342,37 +1334,37 @@ yyreduce:
     break;
 
   case 7:
-#line 178 "asn1-parse.y"
+#line 177 "asn1-parse.y"
     { strcpy(yyval.str,yyvsp[0].str); }
     break;
 
   case 8:
-#line 179 "asn1-parse.y"
+#line 178 "asn1-parse.y"
     { strcpy(yyval.str,yyvsp[0].str); }
     break;
 
   case 9:
-#line 182 "asn1-parse.y"
+#line 181 "asn1-parse.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
   case 10:
-#line 183 "asn1-parse.y"
+#line 182 "asn1-parse.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
   case 11:
-#line 186 "asn1-parse.y"
+#line 185 "asn1-parse.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
   case 12:
-#line 187 "asn1-parse.y"
+#line 186 "asn1-parse.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
   case 13:
-#line 191 "asn1-parse.y"
+#line 190 "asn1-parse.y"
     {
                           yyval.node = NEW_NODE (TYPE_CONSTANT); 
                           set_str_value (yyval.node, yyvsp[-1].str);
@@ -1380,7 +1372,7 @@ yyreduce:
     break;
 
   case 14:
-#line 196 "asn1-parse.y"
+#line 195 "asn1-parse.y"
     {
                           yyval.node = NEW_NODE (TYPE_CONSTANT); 
                           set_name (yyval.node, yyvsp[-3].str); 
@@ -1389,12 +1381,12 @@ yyreduce:
     break;
 
   case 15:
-#line 203 "asn1-parse.y"
+#line 202 "asn1-parse.y"
     { yyval.node=yyvsp[0].node; }
     break;
 
   case 16:
-#line 205 "asn1-parse.y"
+#line 204 "asn1-parse.y"
     {
                     yyval.node = yyvsp[-2].node;
                     append_right (yyvsp[-2].node, yyvsp[0].node);
@@ -1402,7 +1394,7 @@ yyreduce:
     break;
 
   case 17:
-#line 212 "asn1-parse.y"
+#line 211 "asn1-parse.y"
     {
                           yyval.node = NEW_NODE (TYPE_IDENTIFIER);
                           set_name(yyval.node,yyvsp[0].str);
@@ -1410,7 +1402,7 @@ yyreduce:
     break;
 
   case 18:
-#line 217 "asn1-parse.y"
+#line 216 "asn1-parse.y"
     {
                           AsnNode node;
 
@@ -1422,7 +1414,7 @@ yyreduce:
     break;
 
   case 19:
-#line 228 "asn1-parse.y"
+#line 227 "asn1-parse.y"
     { 
                    yyval.node = NEW_NODE (TYPE_CONSTANT); 
                    set_str_value (yyval.node, yyvsp[0].str);
@@ -1430,7 +1422,7 @@ yyreduce:
     break;
 
   case 20:
-#line 233 "asn1-parse.y"
+#line 232 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_CONSTANT);
                    set_name (yyval.node, yyvsp[-3].str); 
@@ -1439,12 +1431,12 @@ yyreduce:
     break;
 
   case 21:
-#line 241 "asn1-parse.y"
+#line 240 "asn1-parse.y"
     { yyval.node=yyvsp[0].node;}
     break;
 
   case 22:
-#line 243 "asn1-parse.y"
+#line 242 "asn1-parse.y"
     {
                           yyval.node=yyvsp[-1].node;
                           append_right (yyval.node, yyvsp[0].node);
@@ -1452,22 +1444,22 @@ yyreduce:
     break;
 
   case 23:
-#line 249 "asn1-parse.y"
+#line 248 "asn1-parse.y"
     { yyval.constant = CLASS_UNIVERSAL;   }
     break;
 
   case 24:
-#line 250 "asn1-parse.y"
+#line 249 "asn1-parse.y"
     { yyval.constant = CLASS_PRIVATE;     }
     break;
 
   case 25:
-#line 251 "asn1-parse.y"
+#line 250 "asn1-parse.y"
     { yyval.constant = CLASS_APPLICATION; }
     break;
 
   case 26:
-#line 255 "asn1-parse.y"
+#line 254 "asn1-parse.y"
     {
                   yyval.node = NEW_NODE (TYPE_TAG); 
                   yyval.node->flags.class = CLASS_CONTEXT;
@@ -1476,7 +1468,7 @@ yyreduce:
     break;
 
   case 27:
-#line 261 "asn1-parse.y"
+#line 260 "asn1-parse.y"
     {
                   yyval.node = NEW_NODE (TYPE_TAG);
                   yyval.node->flags.class = yyvsp[-2].constant;
@@ -1485,12 +1477,12 @@ yyreduce:
     break;
 
   case 28:
-#line 269 "asn1-parse.y"
+#line 268 "asn1-parse.y"
     { yyval.node = yyvsp[0].node; }
     break;
 
   case 29:
-#line 271 "asn1-parse.y"
+#line 270 "asn1-parse.y"
     {
            yyval.node = yyvsp[-1].node;
            yyval.node->flags.explicit = 1;
@@ -1498,7 +1490,7 @@ yyreduce:
     break;
 
   case 30:
-#line 276 "asn1-parse.y"
+#line 275 "asn1-parse.y"
     {
            yyval.node = yyvsp[-1].node;
            yyval.node->flags.implicit = 1;
@@ -1506,7 +1498,7 @@ yyreduce:
     break;
 
   case 31:
-#line 283 "asn1-parse.y"
+#line 282 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_DEFAULT); 
                  set_str_value (yyval.node, yyvsp[0].str);
@@ -1514,7 +1506,7 @@ yyreduce:
     break;
 
   case 32:
-#line 288 "asn1-parse.y"
+#line 287 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_DEFAULT);
                  yyval.node->flags.is_true = 1;
@@ -1522,7 +1514,7 @@ yyreduce:
     break;
 
   case 33:
-#line 293 "asn1-parse.y"
+#line 292 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_DEFAULT);
                  yyval.node->flags.is_false = 1;
@@ -1530,14 +1522,14 @@ yyreduce:
     break;
 
   case 34:
-#line 300 "asn1-parse.y"
+#line 299 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_INTEGER);
                }
     break;
 
   case 35:
-#line 304 "asn1-parse.y"
+#line 303 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_INTEGER);
                  yyval.node->flags.has_list = 1;
@@ -1546,7 +1538,7 @@ yyreduce:
     break;
 
   case 36:
-#line 310 "asn1-parse.y"
+#line 309 "asn1-parse.y"
     {
                  yyval.node = NEW_NODE (TYPE_INTEGER);
                  yyval.node->flags.has_min_max = 1;
@@ -1558,28 +1550,28 @@ yyreduce:
     break;
 
   case 37:
-#line 321 "asn1-parse.y"
+#line 320 "asn1-parse.y"
     {
                 yyval.node = NEW_NODE (TYPE_BOOLEAN);
               }
     break;
 
   case 38:
-#line 327 "asn1-parse.y"
+#line 326 "asn1-parse.y"
     {
             yyval.node = NEW_NODE (TYPE_UTC_TIME);
           }
     break;
 
   case 39:
-#line 331 "asn1-parse.y"
+#line 330 "asn1-parse.y"
     { 
             yyval.node = NEW_NODE (TYPE_GENERALIZED_TIME);
           }
     break;
 
   case 40:
-#line 337 "asn1-parse.y"
+#line 336 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_SIZE);
                yyval.node->flags.one_param = 1;
@@ -1588,7 +1580,7 @@ yyreduce:
     break;
 
   case 41:
-#line 343 "asn1-parse.y"
+#line 342 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_SIZE);
                yyval.node->flags.has_min_max = 1;
@@ -1598,28 +1590,28 @@ yyreduce:
     break;
 
   case 42:
-#line 352 "asn1-parse.y"
+#line 351 "asn1-parse.y"
     {
                yyval.node=yyvsp[0].node;
              }
     break;
 
   case 43:
-#line 356 "asn1-parse.y"
+#line 355 "asn1-parse.y"
     {
                yyval.node=yyvsp[-1].node;
              }
     break;
 
   case 44:
-#line 362 "asn1-parse.y"
+#line 361 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_OCTET_STRING);
                      }
     break;
 
   case 45:
-#line 366 "asn1-parse.y"
+#line 365 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_OCTET_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1628,12 +1620,12 @@ yyreduce:
     break;
 
   case 46:
-#line 373 "asn1-parse.y"
+#line 372 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_UTF8_STRING); }
     break;
 
   case 47:
-#line 375 "asn1-parse.y"
+#line 374 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_UTF8_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1642,12 +1634,12 @@ yyreduce:
     break;
 
   case 48:
-#line 381 "asn1-parse.y"
+#line 380 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_NUMERIC_STRING); }
     break;
 
   case 49:
-#line 383 "asn1-parse.y"
+#line 382 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_NUMERIC_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1656,12 +1648,12 @@ yyreduce:
     break;
 
   case 50:
-#line 390 "asn1-parse.y"
+#line 389 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_PRINTABLE_STRING); }
     break;
 
   case 51:
-#line 392 "asn1-parse.y"
+#line 391 "asn1-parse.y"
     { 
                           yyval.node = NEW_NODE (TYPE_PRINTABLE_STRING);
                           yyval.node->flags.has_size = 1;
@@ -1670,12 +1662,12 @@ yyreduce:
     break;
 
   case 52:
-#line 399 "asn1-parse.y"
+#line 398 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_TELETEX_STRING); }
     break;
 
   case 53:
-#line 401 "asn1-parse.y"
+#line 400 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_TELETEX_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1684,12 +1676,12 @@ yyreduce:
     break;
 
   case 54:
-#line 407 "asn1-parse.y"
+#line 406 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_IA5_STRING); }
     break;
 
   case 55:
-#line 409 "asn1-parse.y"
+#line 408 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_IA5_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1698,12 +1690,12 @@ yyreduce:
     break;
 
   case 56:
-#line 416 "asn1-parse.y"
+#line 415 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_UNIVERSAL_STRING); }
     break;
 
   case 57:
-#line 418 "asn1-parse.y"
+#line 417 "asn1-parse.y"
     {
                            yyval.node = NEW_NODE (TYPE_UNIVERSAL_STRING);
                            yyval.node->flags.has_size = 1;
@@ -1712,12 +1704,12 @@ yyreduce:
     break;
 
   case 58:
-#line 424 "asn1-parse.y"
+#line 423 "asn1-parse.y"
     { yyval.node = NEW_NODE (TYPE_BMP_STRING); }
     break;
 
   case 59:
-#line 426 "asn1-parse.y"
+#line 425 "asn1-parse.y"
     {
                        yyval.node = NEW_NODE (TYPE_BMP_STRING);
                        yyval.node->flags.has_size = 1;
@@ -1726,7 +1718,7 @@ yyreduce:
     break;
 
   case 67:
-#line 447 "asn1-parse.y"
+#line 446 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_CONSTANT);
                    set_name (yyval.node, yyvsp[-3].str); 
@@ -1735,14 +1727,14 @@ yyreduce:
     break;
 
   case 68:
-#line 455 "asn1-parse.y"
+#line 454 "asn1-parse.y"
     {
                         yyval.node=yyvsp[0].node;
                       }
     break;
 
   case 69:
-#line 459 "asn1-parse.y"
+#line 458 "asn1-parse.y"
     {
                         yyval.node=yyvsp[-2].node;
                         append_right (yyval.node, yyvsp[0].node);
@@ -1750,14 +1742,14 @@ yyreduce:
     break;
 
   case 70:
-#line 466 "asn1-parse.y"
+#line 465 "asn1-parse.y"
     {
                      yyval.node = NEW_NODE (TYPE_BIT_STRING);
                    }
     break;
 
   case 71:
-#line 470 "asn1-parse.y"
+#line 469 "asn1-parse.y"
     {
                      yyval.node = NEW_NODE (TYPE_BIT_STRING);
                      yyval.node->flags.has_list = 1;
@@ -1766,7 +1758,7 @@ yyreduce:
     break;
 
   case 72:
-#line 478 "asn1-parse.y"
+#line 477 "asn1-parse.y"
     {
                      yyval.node = NEW_NODE (TYPE_ENUMERATED);
                      yyval.node->flags.has_list = 1;
@@ -1775,14 +1767,14 @@ yyreduce:
     break;
 
   case 73:
-#line 486 "asn1-parse.y"
+#line 485 "asn1-parse.y"
     {
                      yyval.node = NEW_NODE (TYPE_OBJECT_ID);
                    }
     break;
 
   case 74:
-#line 492 "asn1-parse.y"
+#line 491 "asn1-parse.y"
     {
                       yyval.node = NEW_NODE (TYPE_IDENTIFIER);
                       set_str_value (yyval.node, yyvsp[0].str);
@@ -1790,7 +1782,7 @@ yyreduce:
     break;
 
   case 75:
-#line 497 "asn1-parse.y"
+#line 496 "asn1-parse.y"
     {
                       yyval.node = NEW_NODE (TYPE_IDENTIFIER);
                       yyval.node->flags.has_size = 1;
@@ -1800,76 +1792,76 @@ yyreduce:
     break;
 
   case 76:
-#line 503 "asn1-parse.y"
+#line 502 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 77:
-#line 504 "asn1-parse.y"
+#line 503 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 78:
-#line 505 "asn1-parse.y"
+#line 504 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 79:
-#line 506 "asn1-parse.y"
+#line 505 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 81:
-#line 508 "asn1-parse.y"
+#line 507 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 82:
-#line 509 "asn1-parse.y"
+#line 508 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 83:
-#line 510 "asn1-parse.y"
+#line 509 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 84:
-#line 511 "asn1-parse.y"
+#line 510 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 85:
-#line 512 "asn1-parse.y"
+#line 511 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 86:
-#line 513 "asn1-parse.y"
+#line 512 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 87:
-#line 514 "asn1-parse.y"
+#line 513 "asn1-parse.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 88:
-#line 516 "asn1-parse.y"
+#line 515 "asn1-parse.y"
     {
                       yyval.node = NEW_NODE(TYPE_NULL);
                     }
     break;
 
   case 89:
-#line 522 "asn1-parse.y"
+#line 521 "asn1-parse.y"
     {
                              yyval.node = yyvsp[0].node;
                            }
     break;
 
   case 90:
-#line 526 "asn1-parse.y"
+#line 525 "asn1-parse.y"
     {
 /*                               $2->flags.has_tag = 1; */
 /*                               $$ = $2; */
@@ -1881,14 +1873,14 @@ yyreduce:
     break;
 
   case 91:
-#line 537 "asn1-parse.y"
+#line 536 "asn1-parse.y"
     {
                                    yyval.node = yyvsp[0].node;
                                  }
     break;
 
   case 92:
-#line 541 "asn1-parse.y"
+#line 540 "asn1-parse.y"
     {
                                    yyvsp[-1].node->flags.has_default = 1;
                                    yyval.node = yyvsp[-1].node;
@@ -1898,7 +1890,7 @@ yyreduce:
     break;
 
   case 93:
-#line 548 "asn1-parse.y"
+#line 547 "asn1-parse.y"
     {
                                    yyvsp[-1].node->flags.is_optional = 1;
                                    yyval.node = yyvsp[-1].node;
@@ -1906,7 +1898,7 @@ yyreduce:
     break;
 
   case 94:
-#line 555 "asn1-parse.y"
+#line 554 "asn1-parse.y"
     {
                  set_name (yyvsp[0].node, yyvsp[-1].str); 
                  yyval.node = yyvsp[0].node;
@@ -1914,12 +1906,12 @@ yyreduce:
     break;
 
   case 95:
-#line 562 "asn1-parse.y"
+#line 561 "asn1-parse.y"
     { yyval.node=yyvsp[0].node; }
     break;
 
   case 96:
-#line 564 "asn1-parse.y"
+#line 563 "asn1-parse.y"
     {
                       yyval.node=yyvsp[-2].node;
                       append_right (yyval.node, yyvsp[0].node);
@@ -1927,7 +1919,7 @@ yyreduce:
     break;
 
   case 97:
-#line 571 "asn1-parse.y"
+#line 570 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_SEQUENCE);
                    set_down (yyval.node, yyvsp[-1].node);
@@ -1935,7 +1927,7 @@ yyreduce:
     break;
 
   case 98:
-#line 576 "asn1-parse.y"
+#line 575 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_SEQUENCE_OF);
                    set_down (yyval.node, yyvsp[0].node);
@@ -1943,7 +1935,7 @@ yyreduce:
     break;
 
   case 99:
-#line 581 "asn1-parse.y"
+#line 580 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_SEQUENCE_OF);
                    yyval.node->flags.has_size = 1;
@@ -1953,7 +1945,7 @@ yyreduce:
     break;
 
   case 100:
-#line 590 "asn1-parse.y"
+#line 589 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_SET);
                set_down (yyval.node, yyvsp[-1].node);
@@ -1961,7 +1953,7 @@ yyreduce:
     break;
 
   case 101:
-#line 595 "asn1-parse.y"
+#line 594 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_SET_OF);
                set_down (yyval.node, yyvsp[0].node);
@@ -1969,7 +1961,7 @@ yyreduce:
     break;
 
   case 102:
-#line 600 "asn1-parse.y"
+#line 599 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_SET_OF);
                yyval.node->flags.has_size = 1;
@@ -1979,7 +1971,7 @@ yyreduce:
     break;
 
   case 103:
-#line 609 "asn1-parse.y"
+#line 608 "asn1-parse.y"
     {
                   yyval.node = NEW_NODE (TYPE_CHOICE);
                   set_down (yyval.node, yyvsp[-1].node);
@@ -1987,14 +1979,14 @@ yyreduce:
     break;
 
   case 104:
-#line 616 "asn1-parse.y"
+#line 615 "asn1-parse.y"
     {
                yyval.node = NEW_NODE (TYPE_ANY);
              }
     break;
 
   case 105:
-#line 620 "asn1-parse.y"
+#line 619 "asn1-parse.y"
     {
                AsnNode node;
 
@@ -2007,7 +1999,7 @@ yyreduce:
     break;
 
   case 106:
-#line 632 "asn1-parse.y"
+#line 631 "asn1-parse.y"
     {
                set_name (yyvsp[0].node, yyvsp[-2].str);
                yyval.node = yyvsp[0].node;
@@ -2015,7 +2007,7 @@ yyreduce:
     break;
 
   case 107:
-#line 639 "asn1-parse.y"
+#line 638 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_OBJECT_ID);
                    yyval.node->flags.assignment = 1;
@@ -2025,7 +2017,7 @@ yyreduce:
     break;
 
   case 108:
-#line 646 "asn1-parse.y"
+#line 645 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_OBJECT_ID);
                    yyval.node->flags.assignment = 1;
@@ -2037,7 +2029,7 @@ yyreduce:
     break;
 
   case 109:
-#line 655 "asn1-parse.y"
+#line 654 "asn1-parse.y"
     {
                    yyval.node = NEW_NODE (TYPE_INTEGER);
                    yyval.node->flags.assignment = 1;
@@ -2047,22 +2039,22 @@ yyreduce:
     break;
 
   case 110:
-#line 663 "asn1-parse.y"
+#line 662 "asn1-parse.y"
     { yyval.node = yyvsp[0].node; }
     break;
 
   case 111:
-#line 664 "asn1-parse.y"
+#line 663 "asn1-parse.y"
     { yyval.node = yyvsp[0].node; }
     break;
 
   case 112:
-#line 668 "asn1-parse.y"
+#line 667 "asn1-parse.y"
     { yyval.node = yyvsp[0].node; }
     break;
 
   case 113:
-#line 670 "asn1-parse.y"
+#line 669 "asn1-parse.y"
     { 
                          yyval.node = yyvsp[-1].node;
                          append_right (yyval.node, yyvsp[0].node);
@@ -2070,7 +2062,7 @@ yyreduce:
     break;
 
   case 114:
-#line 677 "asn1-parse.y"
+#line 676 "asn1-parse.y"
     {
                      yyval.node = NEW_NODE (TYPE_OBJECT_ID);
                      set_down (yyval.node, yyvsp[-1].node);
@@ -2079,12 +2071,12 @@ yyreduce:
     break;
 
   case 115:
-#line 685 "asn1-parse.y"
+#line 684 "asn1-parse.y"
     { yyval.node=NULL;}
     break;
 
   case 116:
-#line 687 "asn1-parse.y"
+#line 686 "asn1-parse.y"
     {
                   AsnNode node;
 
@@ -2098,17 +2090,17 @@ yyreduce:
     break;
 
   case 117:
-#line 699 "asn1-parse.y"
+#line 698 "asn1-parse.y"
     { yyval.constant = CONST_EXPLICIT; }
     break;
 
   case 118:
-#line 700 "asn1-parse.y"
+#line 699 "asn1-parse.y"
     { yyval.constant = CONST_IMPLICIT; }
     break;
 
   case 119:
-#line 706 "asn1-parse.y"
+#line 705 "asn1-parse.y"
     {
                  AsnNode node;
                  
@@ -2145,8 +2137,8 @@ yyreduce:
 
     }
 
-/* Line 1010 of yacc.c.  */
-#line 2150 "asn1-parse.c"
+/* Line 999 of yacc.c.  */
+#line 2142 "asn1-parse.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2187,33 +2179,18 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
-	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx;
+	  int yyx, yycount;
 
+	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  int yyxbegin = yyn < 0 ? -yyn : 0;
-
-	  /* Stay within bounds of both yycheck and yytname.  */
-	  int yychecklim = YYLAST - yyn;
-	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
-	  int yycount = 0;
-
-	  yyprefix = ", expecting ";
-	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+	  for (yyx = yyn < 0 ? -yyn : 0;
+	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      {
-		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
-		yycount += 1;
-		if (yycount == 5)
-		  {
-		    yysize = 0;
-		    break;
-		  }
-	      }
-	  yysize += (sizeof ("syntax error, unexpected ")
-		     + yystrlen (yytname[yytype]));
+	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
+	  yysize += yystrlen ("syntax error, unexpected ") + 1;
+	  yysize += yystrlen (yytname[yytype]);
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -2222,13 +2199,16 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yyprefix = ", expecting ";
-		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+		  yycount = 0;
+		  for (yyx = yyn < 0 ? -yyn : 0;
+		       yyx < (int) (sizeof (yytname) / sizeof (char *));
+		       yyx++)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			yyp = yystpcpy (yyp, yyprefix);
+			const char *yyq = ! yycount ? ", expecting " : " or ";
+			yyp = yystpcpy (yyp, yyq);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yyprefix = " or ";
+			yycount++;
 		      }
 		}
 	      yyerror (yymsg);
@@ -2249,27 +2229,25 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      if (yychar <= YYEOF)
+      /* Return failure if at end of input.  */
+      if (yychar == YYEOF)
         {
-          /* If at end of input, pop the error token,
-	     then the rest of the stack, then return failure.  */
-	  if (yychar == YYEOF)
-	     for (;;)
-	       {
-		 YYPOPSTACK;
-		 if (yyssp == yyss)
-		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp);
-	       }
+	  /* Pop the error token.  */
+          YYPOPSTACK;
+	  /* Pop the rest of the stack.  */
+	  while (yyss < yyssp)
+	    {
+	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+	      yydestruct (yystos[*yyssp], yyvsp);
+	      YYPOPSTACK;
+	    }
+	  YYABORT;
         }
-      else
-	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval);
-	  yychar = YYEMPTY;
 
-	}
+      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+      yydestruct (yytoken, &yylval);
+      yychar = YYEMPTY;
+
     }
 
   /* Else will try to reuse lookahead token after shifting the error
@@ -2277,27 +2255,9 @@ yyerrlab:
   goto yyerrlab1;
 
 
-/*---------------------------------------------------.
-| yyerrorlab -- error raised explicitly by YYERROR.  |
-`---------------------------------------------------*/
-yyerrorlab:
-
-#ifdef __GNUC__
-  /* Pacify GCC when the user code never invokes YYERROR and the label
-     yyerrorlab therefore never appears in user code.  */
-  if (0)
-     goto yyerrorlab;
-#endif
-
-  yyvsp -= yylen;
-  yyssp -= yylen;
-  yystate = *yyssp;
-  goto yyerrlab1;
-
-
-/*-------------------------------------------------------------.
-| yyerrlab1 -- common code for both syntax error and YYERROR.  |
-`-------------------------------------------------------------*/
+/*----------------------------------------------------.
+| yyerrlab1 -- error raised explicitly by an action.  |
+`----------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
@@ -2321,8 +2281,9 @@ yyerrlab1:
 
       YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
       yydestruct (yystos[yystate], yyvsp);
-      YYPOPSTACK;
-      yystate = *yyssp;
+      yyvsp--;
+      yystate = *--yyssp;
+
       YY_STACK_PRINT (yyss, yyssp);
     }
 
@@ -2371,7 +2332,7 @@ yyreturn:
 }
 
 
-#line 739 "asn1-parse.y"
+#line 738 "asn1-parse.y"
 
 
 const char *key_word[]={
@@ -2524,7 +2485,7 @@ new_node (struct parser_control_s *parsectl, node_type_t type)
   node->type = type;
   node->off = -1;
   node->link_next = parsectl->all_nodes;
-  parsectl->all_nodes = node->link_next;
+  parsectl->all_nodes = node;
 
   return node;
 }
